import { useEffect, useState } from 'react';
import paginationStyles from "./styles/pagination.module.css";
import previousIcon from "./icons/previousIcon.svg"
import nextIcon from "./icons/nextIcon.svg"
import firstIcon from "./icons/firstIcon.svg"
import lastIcon from "./icons/lastIcon.svg"

let pageLimits = 10;

const CustomEllipsisPagination = (props) => {
    
    const [active, setActive] = useState(1);
    const[itemsListed,setItemListed] = useState({
        min:0,
        max:10
    });

    const {pageCount} = props;
    
  


    const handler = (value) => {
        setActive(value)
        props.handler(value)
    }

    let items = [];
    if(pageCount){
        for (let number = 1; number <= pageCount; number++) {
            items.push(
                <li className={number === active ? paginationStyles.active : ""}
                    key={number}
                    onClick={() => handler(number)}>
                    {number}
                </li>
            );
        }
    }

    const handleDots = (type) => {
        if(type === 'previous'){
            setActive(itemsListed?.min - 9);
        }
        else{
            setActive(itemsListed?.max + 1);
        }
    }

      useEffect(() => {
        props.handler(active)
        if(active > itemsListed?.max){
            setItemListed({min: itemsListed?.max,max: itemsListed?.max + pageLimits })
        }
        else if(active <= itemsListed?.min){ 
            setItemListed({min: itemsListed?.min - pageLimits,max: itemsListed?.min })
        }
      },[active,itemsListed])


    return (
        <ul className={paginationStyles.pagination_custom}>
            <li style={{display:'none'}}></li>
            <li className={active === 1 ? 'paginationArrowsInActive' : 'paginationArrowsActive' } onClick={() => handler(1)}><img src={firstIcon} width="15px" height="15px" /></li>
            <li className={active === 1 ? 'paginationArrowsInActive' : 'paginationArrowsActive' } onClick={() => handler(active === 1 ? 1 : active - 1)}><img src={previousIcon}  width="8px" height="14px" /></li>
            {itemsListed?.max >= pageLimits && active > pageLimits ? <li onClick={() => handleDots('previous')}>...</li> : null}
            {items.slice(itemsListed?.min,itemsListed?.max)}
            {pageCount > 10 && itemsListed?.min == 0 || itemsListed?.max < pageCount && pageCount > 10 ? <li onClick={() => handleDots('')}>...</li> : null}
            <li className={active === pageCount ? 'paginationArrowsInActive' : 'paginationArrowsActive' } onClick={() => handler(active === pageCount ? pageCount : active + 1)}><img src={nextIcon} width="8px" height="14px" /></li>
            <li className={active === pageCount ? 'paginationArrowsInActive' : 'paginationArrowsActive' } onClick={() => handler(pageCount)}><img src={lastIcon} width="15px" height="15px" /></li>
            <li style={{display:'none'}}></li>
        </ul>
    );
}

export default CustomEllipsisPagination;